Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/newlib-cygwin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/winsup
diff options
context:
space:
mode:
authorCorinna Vinschen <corinna@vinschen.de>2011-12-12 15:03:01 +0400
committerCorinna Vinschen <corinna@vinschen.de>2011-12-12 15:03:01 +0400
commit7a7a9e7179155d9202cddb7d2660726f750fd195 (patch)
tree8b0ba855097f9fa5f8d28c2cff61585315f4d8cc /winsup
parent74e0bcfc0f3fc3c38941675d2338b3d11f41989a (diff)
* mount.cc (fs_info::update): Set has_buggy_reopen for Netapps as well.
Diffstat (limited to 'winsup')
-rw-r--r--winsup/cygwin/ChangeLog4
-rw-r--r--winsup/cygwin/mount.cc6
2 files changed, 7 insertions, 3 deletions
diff --git a/winsup/cygwin/ChangeLog b/winsup/cygwin/ChangeLog
index ef7fa4d04..f51753725 100644
--- a/winsup/cygwin/ChangeLog
+++ b/winsup/cygwin/ChangeLog
@@ -1,4 +1,8 @@
2011-12-12 Corinna Vinschen <vinschen@redhat.com>
+
+ * mount.cc (fs_info::update): Set has_buggy_reopen for Netapps as well.
+
+2011-12-12 Corinna Vinschen <vinschen@redhat.com>
Christopher Faylor <me.cygwin2011@cgf.cx>
* dcrt0.cc (wow64_respawn): New static variable.
diff --git a/winsup/cygwin/mount.cc b/winsup/cygwin/mount.cc
index 895592525..bfb63f801 100644
--- a/winsup/cygwin/mount.cc
+++ b/winsup/cygwin/mount.cc
@@ -393,10 +393,10 @@ fs_info::update (PUNICODE_STRING upath, HANDLE in_vol)
away since at least some of them are not capable either. */
has_dos_filenames_only (is_netapp () || is_nwfs ()
|| is_ncfsd () || is_cifs ());
- /* NWFS does not grok re-opening a file by handle. It only
- supports this if the filename is non-null and the handle is
+ /* Netapp and NWFS don't grok re-opening a file by handle. They
+ only support this if the filename is non-null and the handle is
the handle to a directory. NcFsd IR10 is supposed to be ok. */
- has_buggy_reopen (is_nwfs ());
+ has_buggy_reopen (is_netapp () || is_nwfs ());
}
}
if (!got_fs ()